# Braspag

[![Build Status](https://secure.travis-ci.org/TracyWebTech/braspag.png?branch=master)](https://travis-ci.org/TracyWebTech/braspag)

## Getting Started

### Dependencies

The following dependencies are automaticatly installed by the setup.py:

* Jinja2

### Installation

1. Clone the repository to your machine.
2. Run `python setup.py install` from the root of your local clone.

# Documentation

https://braspag.readthedocs.org/

# LICENSE

All source code here is available under the [LGPL Version 3][] license, unless
otherwise indicated.

  [LGPL Version 3]: http://www.gnu.org/licenses/lgpl.txt
